S3 Dumps
==========

.. image:: https://travis-ci.org/rakeshgunduka/s3_dumps.png?branch=master
    :alt: Build Status
    :target: https://travis-ci.org/rakeshgunduka/s3_dumps


This is fork of S3 Backups <https://github.com/epicserve/s3-backups>. 
Rewritten code to work with boto3 and upload to Amazon s3 and DigitalOcean Spaces. 

Installation
------------

To install s3-dumps::

    $ sudo pip install s3_dumps

